@@ -10,7 +10,7 @@ use Encode qw(decode encode);
 use Mail::Sendmail '0.79_16';
 use MIME::Base64;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 ################################################################################
 
@@ -50,6 +50,10 @@ sub new
     $mail->{attachments}          ||= {};
     $mail->{attachments_size_max} ||=  0; #no limit "-1" means no attachment allowed
 
+    $mail->{commit}   ||= 0;
+
+    $mail->send() if $mail->{commit};
+
     return $mail;
 }
 
@@ -59,10 +63,12 @@ sub send
 {
     my ( $self, $ARG ) = ( shift, shift );
 
-    $ARG->{to} || $ARG->{cc} || die 'No to: or cc: email address given!';
+    return 'No address! Please set [to] or/and [cc] fileds.' unless $ARG->{to} || $ARG->{cc} || $self->{to} || $self->{cc};
 
     my $charset  = $ARG->{charset} || $self->{charset} || 'utf-8';
     my $type     = $ARG->{type}    || $self->{type}    || 'text/plain';
+    my $subject  = $ARG->{subject} || $self->{subject} || '';
+    my $message  = $ARG->{message} || $self->{message} || '';
 
     my $boundary = "====" . time() . "====";
 
@@ -72,15 +78,13 @@ sub send
     # new line with a statemant of the encoding, so - as a the
     # third parameter - the charset is sent to the function.
 
-    my $subject = $ARG->{subject} || $self->{subject} || '';
-
     my $flnoc = 67;
     my $nlnoc = 78;
     my $bol   = " =?$charset?Q?";
     my $eol   = "?=\n";
 
     {
-        # this part consider multibytes characters and keep that folding
+        # this part consider multibyte characters and keep that folding
         # does  not  divide  the  multibyte  characters  into  two lines.
         # The  reason  is  that  some  email clients are not able to put
         # together these separated bytes into one character.
@@ -141,7 +145,7 @@ sub send
     $mail{'Message'} = "$boundary\n"
     ."Content-Type: $type; charset=$charset; format=flowed\n"
     ."Content-Transfer-Encoding: 8bit\n\n"
-    .$ARG->{'message'}."\n";
+    ."$message\n";
 
 #    ."Content-Transfer-Encoding: quoted-printable\n\n"
 #    .encode_qp( $ARG->{'message'}, {} )."\n";
@@ -149,13 +153,33 @@ sub send
     $ARG->{attachments}          ||= $self->{attachments} || {};
     $ARG->{attachments_size_max} ||= $self->{attachments_size_max} || 0; #no limit "-1" means no attachment allowed
 
-    return "Attachments are not allowed whereas some are preperad to send!" if $ARG->{attachments} && $ARG->{attachments_size_max} < 0;
+    $ARG->{attachments_size_max}=~s/[B ]//g;
+    if ( $ARG->{attachments_size_max} =~ /^(-\d+)$|^(\d+)(|k|K|m|M|t|T)?\s*$/ )
+    {
+        if ( $1 ) { $ARG->{attachments_size_max} = $1
+
+        } else {
+
+            $ARG->{attachments_size_max} =                      $2 if $3 eq 'B' || !$3;
+            $ARG->{attachments_size_max} =               1000 * $2 if $3 eq 'k';
+            $ARG->{attachments_size_max} =               1024 * $2 if $3 eq 'K';
+            $ARG->{attachments_size_max} =        1000 * 1000 * $2 if $3 eq 'm';
+            $ARG->{attachments_size_max} =        1024 * 1024 * $2 if $3 eq 'M';
+            $ARG->{attachments_size_max} = 1000 * 1000 * 1000 * $2 if $3 eq 't';
+            $ARG->{attachments_size_max} = 1024 * 1024 * 1024 * $2 if $3 eq 'T';
+        }
+    }
+    else {
+      return 'Malform in attachments_size_max='.$ARG->{attachments_size_max}.'! Accepted form is: positive or negative integer plus optional one of the letters: (k,K,m,M,t,T).'
+    }
+
+    return "Attachments are not allowed whereas some are preperad to send!" if %{$ARG->{attachments}} && $ARG->{attachments_size_max} < 0;
     # attachment files are packed one by one into the message part each divided by boundary
 
     # checking attachments:
-    foreach my $fileName ( sort keys %{$ARG->{'attachments'}} ) {
+    foreach my $fileName ( sort keys %{$ARG->{attachments}} ) {
 
-           my $fileLocation = $ARG->{'attachments'}->{$fileName};
+           my $fileLocation = $ARG->{attachments}->{$fileName};
 
         # if does not exists:
         return "Attachment does not exists! [$fileLocation]" unless -f $fileLocation;
@@ -167,8 +191,8 @@ sub send
     }
 
 
-    foreach my $fileName ( sort keys %{$ARG->{'attachments'}} ) {
-        my $fileLocation = $ARG->{'attachments'}->{$fileName};
+    foreach my $fileName ( sort keys %{$ARG->{attachments}} ) {
+        my $fileLocation = $ARG->{attachments}->{$fileName};
         if (open (my $F, $fileLocation )) {
             my $input_record_separator = $/;
             binmode $F; undef $/;
@@ -323,7 +347,7 @@ sub encode_qp
 
 =head1 NAME
 
-    Mail::Sendmail::Enhanced v.0.02 = L<Mail::Sendmail> + encoding + attachments (pure Perl)
+    Mail::Sendmail::Enhanced v.0.03 - Pure Perl email sender with multibyte characters encoding and easy attachments managment
 
 =head1 SYNOPSIS
 
@@ -334,8 +358,11 @@ sub encode_qp
 
   use Mail::Sendmail::Enhanced;
 
-  my $MAIL = Mail::Sendmail::Enhanced-> new(
-    charset     => 'UTF-8',
+  # This part simulate the general setup of application mailer.
+  # It sets smtp server and size limit of attachments (1MB)
+  # This configuration is set by admin.
+  my $mail = Mail::Sendmail::Enhanced-> new(
+    charset     => 'cp1250',
     smtp        => 'Your SMTP server',
     from        => 'Your mail',
     user        => 'user',
@@ -346,122 +373,178 @@ sub encode_qp
       'name for email of the file1' => 'OS file1 location',
       'name for email of the file2' => 'OS file2 location',
     },
-    attachments_size_max => 0,
+    attachments_size_max => '1MB',
+    commit      => 0,
   );
 
-  for (1..2) {
-    print $MAIL-> send( {
-      to    => 'author of the module: <wb@webswing.co.uk>',
-      subject  => "Subject longer than 80 characters with Polish letters: lowercase: ąćęłńóśźż and uppercase: ĄĆĘŁŃÓŚŹŻ.",
-      message  => "This is the message nr $_. in the character encoding UTF-8.
+  # This part simulate how clients can use the mailer.
+  # Configuration here is set by clients themself.
+  my @client = qw(John Henry Newman);
+  for (@client) {
 
-      This is an example of using UTF-8 Polish letters in an email subject field: encoded and longer than 80 characters.",
+    my $lowercase = chr(185).chr(230).chr(234).chr(179).chr(241).chr(243).chr(156).chr(159).chr(191);
+    my $uppercase = chr(165).chr(198).chr(202).chr(163).chr(209).chr(211).chr(140).chr(143).chr(175);
+
+    print $mail-> send( {
+      to    => 'author of the module: <wb@webswing.co.uk>',
+      subject  => "Subject longer than 80 characters with Polish letters: lowercase: $lowercase and uppercase: $uppercase.",
+      message  => "This is the message from $_ in the character encoding ".$mail->{charset}.".
+
+      This is an example of mailing Polish letters in a header field named \"Subject\".
+      Additionally this field is longer than 80 characters.
+
+      Additional text:
+      Polish lowercase letters: $lowercase
+      Polish uppercase letters: $uppercase
+      ",
+    });
+  }
 
   __END__
 
 =head1 DESCRIPTION
 
-Enhanced version of the module Mail::Sendmail with multibytes encoding
-and attachments. It is pure Perl solution.
+Mail::Sendmail::Enhanced  is  an  enhanced   version  of  the module
+L<Mail::Sendmail>. It is still pure Perl solution. In the module the
+problem  of encoding  multibyte  characters in L<Mail::Sendmail> was
+solved. Some procedure of sending  very easily a list of attachments
+was prepared.
 
-From L<Mail::Sendmail>:
+After preparing  multibyte  characters encoding and building message
+with  attachments the  module calls  I<sendmail>  function  from the
+L<Mail::Sendmail> module which does all the job.So please read there
+in L<Mail::Sendmail> about how to set up connections to email servers.
+This module behaves identically.
 
-"Simple  platform  independent  e-mail  from  your  perl script. Only
-requires Perl 5 and a network connection. Mail::Sendmail takes a hash
-with  the  message  to  send  and sends it to your mail server. It is
-intended to be very easy to setup and use."
+As already mentioned this adds two things:
 
+1. Multibyte characters encoding - which uses refurbish and imported
+function I<encode_qp> from the module L<MIME::QuotedPrint::Perl>.
 
-In L<Mail::Sendmail::Enhanced> two things were added:
+The  problem  with  encoding  multibyte  characters  was that simple
+implemented encoding -  especially  in the "Subject:" field of email
+header - results  that some characters are  divided between two rows
+when long  lines are folded.  Some email clients are not able to put
+together these  separated bytes into  one character  and letters are
+displeyed inproperly. The new encoding function keeps  bytes of  one
+character in one folded row.
 
-1. Encoding - which uses the refurbish function B<encode_qp> from the
-module L<MIME::QuotedPrint::Perl> which  is put into  the current one.
-This  is  pure Perl solution.
-
-Simple  encoding  multibytes  character long header field  "Subject:"
-caused that  some characters were  divided  between  two folded rows.
-Some email clients are not able to put together these separated bytes
-into one character  and words were displeyed  inproperly.  Since  the
-version 0.02 this problem is solved by keeping bytes of one character
-in one folded row.
-
-2. Attachments - which allows to add attachments easily.  It makes it
-by using the technique connected with "multipart/mixed" and "boundary"
-'Content-Type' attribute.
-
-List of files to send (attachments) is given as a simple hash:
+2. Simple attachments managment. List of attachments is a hash:
 
   attachments => {
     'name for email of the file1' => 'OS file1 location',
     'name for email of the file2' => 'OS file2 location',
   },
 
-where the keys of the hash are "public" (in email) names of files and
-values of the hash are these files OS locations, respectively.
+where  the keys are  the  attachments email names and the values are
+OS locations.
 
-It possible to do additional specificification of sending attachments
-throug the parameter B<attachments_size_max>. The possible values are:
+It is possible to add some control to sending attachment. It is done
+by the parameter B<attachments_size_max>. Possible values are:
 
-  attachments_size_max =>  0,       # No limit for sizes of attachments
 
-  attachments_size_max => -1,       # Negative value means that sending attachments is forbidden.
-                                    # Every try of sending them with this value negative is fatal one.
+  attachments_size_max => -1,         # Negative value means that sending attachments is forbidden.
+                                      # Every try of sending them with this value negative is fatal one.
 
-  attachments_size_max => 100000,   # Positive value is maximum size limit of attachment.
-                                    # When attachment is bigger then fatal error is return;
+  attachments_size_max =>  0,         # No size limit of attachments
+
+  attachments_size_max => '50 000 B', # Positive value is a maximum size of attachment.
+                                      # When size is bigger then fatal error is return.
+                                      # Spaces and the letter B (byte) are ignored.
+
+                                      # shorthand for sizes: k, K, m, M:
+  attachments_size_max => '100k',     # k = 1000,         so maximum =   100 000
+  attachments_size_max => '100 K',    # K = 1024,         so maximum =   102 400
+  attachments_size_max => '2 m',      # m = 1000x1000,    so maximum = 1 000 000
+  attachments_size_max => '2M',       # M = 1024x1024,    so maximum = 1 048 576
+
+
+=head1 INTERFACE
+
+Interface L<Mail::Sendmail::Enhanced>, gets two methods:
+
+=head2 new()
+
+The method I<new> creates mail object.
+
+=head2 send()
+
+The method I<send> sends mail.
+
+Arguments  of both  methods  are  the  same  and  discussed  earlier.
+Dispersing  data  between  I<new>  and  I<send>  is  fully  optional.
+Assuming that we have three hashes %n, %s and %d which fullfiled the
+abstract equality:
+
+    "%n + %s = %d"
+
+all the three ways of sending email have the same effect:
+
+    1. my $mail = Mail::Sendmail::Enhanced->new(%n); $mail->send(%s);
+
+    2. my $mail = Mail::Sendmail::Enhanced->new(); $mail->send(%d);
+
+    3. my $mail = Mail::Sendmail::Enhanced->new(%d); $mail->send();
+
+This third way can be replaced by only one call with additional argument
+"commit" with the value 1 (look back at the SYNOPSIS):
+
+    commit => 1,
+
+in that case email is sent at the end of the method I<new>.
 
 
 =head1 BUGS
 
-Please report any bugs or feature requests to
-C<bug-mail-sendmail-enhanced at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Mail-Sendmail-Enhanced>.
-I will be notified, and then you'll automatically be notified of progress on your
-bug as I make changes.
+Please report any bugs or feature requests to C<bug-mail-sendmail-enhanced at rt.cpan.org>, or through
+the web interface at  L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Mail-Sendmail-Enhanced>. I will
+be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 LICENSE AND COPYRIGHT
 
 Copyright (C) 2015 Waldemar Biernacki, C<< <wb at webswing.co.uk> >>
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
+This program is free software; you can redistribute it and/or modify
+it under the terms of the the Artistic License (2.0). You may obtain
+a copy of the full license at:
 
 L<http://www.perlfoundation.org/artistic_license_2_0>
 
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
+Any use, modification, and distribution of the Standard  or Modified
+Versions is governed by this Artistic License. By  using,  modifying
+or distributing  the Package, you  accept  this license.  Do not use,
+modify, or distribute the Package, if you do not accept this license.
 
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
+If  your  Modified  Version has been derived from a Modified Version
+made  by someone  other  than  you, you are nevertheless required to
+ensure that your Modified Version complies with the  requirements of
+this license.
 
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
+This  license  does  not  grant  you  the right to use any trademark,
+service mark, tradename, or logo of the Copyright Holder.
 
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
+This license includes the non-exclusive,  worldwide,  free-of-charge
+patent  license to make, have made, use, offer to sell, sell, import
+and otherwise transfer the Package with respect to any patent claims
+licensable by the Copyright Holder that are necessarily infringed by
+the  Package.  If  you  institute  patent  litigation  (including  a
+cross-claim  or counterclaim)  against  any  party alleging that the
+Package constitutes direct or contributory patent infringement, then
+this Artistic License to you shall terminate  on the date  that such
+litigation is filed.
 
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+Disclaimer of Warranty: THE PACKAGE IS  PROVIDED  BY  THE  COPYRIGHT
+HOLDER AND CONTRIBUTORS "AS IS' AND WITHOUT  ANY EXPRESS  OR IMPLIED
+WARRANTIES. THE  IMPLIED WARRANTIES OF  MERCHANTABILITY, FITNESS FOR
+A  PARTICULAR PURPOSE, OR  NON-INFRINGEMENT  ARE  DISCLAIMED  TO THE
+EXTENT  PERMITTED  BY  YOUR  LOCAL  LAW. UNLESS  REQUIRED BY LAW, NO
+COPYRIGHT  HOLDER  OR  CONTRIBUTOR  WILL  BE  LIABLE  FOR ANY DIRECT,
+INDIRECT, INCIDENTAL, OR  CONSEQUENTIAL  DAMAGES  ARISING IN ANY WAY
+OUT OF THE USE OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGE.
 
 =head1 SEE ALSO
 
 L<Mail::Sendmail>, L<MIME::QuotedPrint::Perl>
 
 =cut
-
